@@ -13,21 +13,22 @@
 
 #ifndef BARINSTANCING_H
 #define BARINSTANCING_H
+#include <QtGraphs/qgraphsglobal.h>
+#include <private/qquick3dinstancing_p.h>
 
-#include <QtQuick3D/private/qquick3dinstancing_p.h>
-
-struct BarItemHolder {
+struct BarItemHolder
+{
     QVector3D position = {.0f, .0f, .0f};
-    QQuaternion rotation;
-    QVector3D eulerRotation = {.0f, .0f, .0f};
+    QQuaternion rotation = {1.f, .0f, .0f, .0f};
     QVector3D scale = {.0f, .0f, .0f};
     QPoint coord;
     float heightValue = .0f;
     bool selectedBar = false;
-    QColor color = {0, 0, 0};;
+    QColor color = {0, 0, 0};
+    ;
 };
 
-class BarInstancing : public QQuick3DInstancing
+class Q_GRAPHS_EXPORT BarInstancing : public QQuick3DInstancing
 {
     Q_OBJECT
 public:
@@ -38,8 +39,8 @@ public:
     void setDataArray(const QList<BarItemHolder *> &newDataArray);
 
     void markDataDirty();
-    bool rangeGradient() const;
-    void setRangeGradient(bool newRangeGradient);
+    bool transparency() const;
+    void setTransparency(bool newTransparencyValue);
 
     void clearDataArray();
 
@@ -51,7 +52,7 @@ private:
     QList<BarItemHolder *> m_dataArray;
     int m_instanceCount = 0;
     bool m_dirty = true;
-    bool m_rangeGradient = false;
+    bool m_transparency = false;
 };
 
 #endif // BARINSTANCING_H
