@@ -14,8 +14,8 @@
 #ifndef QCUSTOMLABELITEM_P_H
 #define QCUSTOMLABELITEM_P_H
 
-#include "qcustom3dlabel.h"
 #include "qcustom3ditem_p.h"
+#include "qcustom3dlabel.h"
 
 QT_BEGIN_NAMESPACE
 
@@ -24,11 +24,13 @@ class QCustom3DLabelPrivate : public QCustom3DItemPrivate
     Q_DECLARE_PUBLIC(QCustom3DLabel)
 
 public:
-    QCustom3DLabelPrivate(QCustom3DLabel *q);
-    QCustom3DLabelPrivate(QCustom3DLabel *q, const QString &text, const QFont &font,
-                          const QVector3D &position, const QVector3D &scaling,
+    QCustom3DLabelPrivate();
+    QCustom3DLabelPrivate(const QString &text,
+                          const QFont &font,
+                          QVector3D position,
+                          QVector3D scaling,
                           const QQuaternion &rotation);
-    virtual ~QCustom3DLabelPrivate();
+    ~QCustom3DLabelPrivate() override;
 
     void resetDirtyBits();
 
